"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const ubuntuCfgFilePath = '/etc/network/interfaces';
let ubuntuCfgLines = [];
const writeNetworkInterface = () => fs_1.writeFileSync(ubuntuCfgFilePath, ubuntuCfgLines.join('\n'));
const getItemFromLines = name => {
    let value = '';
    ubuntuCfgLines.find(line => {
        if (line.indexOf(name + ' ') === 0) {
            value = line.replace(name + ' ', '');
            return true;
        }
        return false;
    });
    return value;
};
const setItemFromLines = (name, value) => {
    const found = ubuntuCfgLines.find((line, index) => {
        if (line.indexOf(name + ' ') === 0) {
            ubuntuCfgLines[index] = name + ' ' + value;
            return true;
        }
        return false;
    });
    if (!found) {
        ubuntuCfgLines.push(name + ' ' + value);
    }
    writeNetworkInterface();
};
const getItemsFromLines = name => {
    let values = [];
    ubuntuCfgLines.map(line => {
        if (line.indexOf(name + ' ') === 0) {
            values.push(line.replace(name + ' ', ''));
            return true;
        }
        return false;
    });
    return values;
};
const setItemsFromLines = (name, values) => {
    let indexes = [];
    ubuntuCfgLines.map((line, index) => {
        if (line.indexOf(name + ' ') === 0) {
            indexes.unshift(index);
        }
    });
    indexes.map((i, index) => {
        if (indexes.length === index + 1) {
            ubuntuCfgLines.splice(i, 1, ...values.map(value => `${name} ${value}`));
        }
        else {
            ubuntuCfgLines.splice(i, 1);
        }
    });
    if (!indexes.length) {
        ubuntuCfgLines = ubuntuCfgLines.concat(values.map(value => `${name} ${value}`));
    }
    writeNetworkInterface();
};
const UbuntuImpl = class {
    /**
     * /etc/network/interfaces
    <pre>
        auto lo
        iface lo inet loopback
        auto eth0
        iface eth0 inet static
        address 118.193.214.104
        netmask 255.255.255.224
        gateway 118.193.214.97
        dns-nameservers 1.2.4.8
        dns-nameservers 114.114.114.114
    </pre>
    */
    constructor() {
        const str = fs_1.readFileSync(ubuntuCfgFilePath).toString();
        ubuntuCfgLines = str.split(/[\r\n]+/).map(line => line.trim());
    }
    getAddress() {
        return getItemFromLines('address');
    }
    setAddress(address) {
        return setItemFromLines('address', address);
    }
    getNetmask() {
        return getItemFromLines('netmask');
    }
    setNetmask(netmask) {
        return setItemFromLines('netmask', netmask);
    }
    getGateway() {
        return getItemFromLines('gateway');
    }
    setGateway(gateway) {
        return setItemFromLines('gateway', gateway);
    }
    getDNS() {
        return getItemsFromLines('dns-nameservers');
    }
    setDNS(dns) {
        return setItemsFromLines('dns-nameservers', dns);
    }
};
const RedhatImpl = class extends UbuntuImpl {
};
exports.default = fs_1.existsSync('/etc/redhat-release') ? new RedhatImpl() : new UbuntuImpl();
