"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const FSUtil_1 = require("../../util/FSUtil");
const Date_1 = require("../../util/Date");
const TimeImpl = class {
    getTime() {
        return Number(child_process_1.execSync(`date +"%s"`).toString()) * 1000;
    }
    setTime(t) {
        const time = new Date();
        time.setTime(t);
        const fmt = Date_1.format(time, 'MMddHHmmyy.ss');
        child_process_1.execSync(`date ${fmt}`);
    }
};
const TIME_ZONE_BASE = '/usr/share/zoneinfo/';
const ZoneImpl = class {
    tree() {
        return FSUtil_1.readDirDeepSync(TIME_ZONE_BASE);
    }
    getZone() {
        return child_process_1.execSync('cat /etc/timezone').toString().trim();
    }
    setZone(zone) {
        return FSUtil_1.PromiseExec(`timedatectl set-timezone ${zone}`);
    }
};
let ntpServer = 'ntp.ubuntu.com';
const NTPImpl = class {
    getEnabled() {
        let info = child_process_1.execSync('timedatectl | grep Network').toString().match(/\:\s*(\w+)/);
        return !!info && info[1] === 'yes';
    }
    setEnabled(enable) {
        return FSUtil_1.PromiseExec(`timedatectl set-ntp ${enable}`);
    }
    setServer(server) {
        ntpServer = server;
        return FSUtil_1.PromiseExec(null);
    }
    getServer() {
        return ntpServer;
    }
};
const time = new TimeImpl();
const zone = new ZoneImpl();
const ntp = new NTPImpl();
exports.default = {
    time,
    zone,
    ntp
};
